# ListDelegatesResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**delegates** | [**list[Delegate]**](Delegate.md) | List of the user&#x27;s delegates (with any verification status). If an account doesn&#x27;t have delegates, this field doesn&#x27;t appear. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

